@@ -75,7 +75,7 @@ class CfnMicrosoftAD(
             short_name=short_name,
         )
 
-        jsii.create(CfnMicrosoftAD, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -468,7 +468,7 @@ class CfnSimpleAD(
             short_name=short_name,
         )
 
-        jsii.create(CfnSimpleAD, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
